<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>Klikk for å gå tilbake til applikasjonen</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Laster ned</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>Opprensking</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 enheter</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Filnavn</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Forsøk igjen</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Åpne</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publiser podcast til YouTube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tittel</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Forfatter</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>Tavle</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenter</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>Stylus</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>Bakgrunnsalternativer</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>Endre bakgrunn</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Angre</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Gjør om igjen</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Forrige</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Forrige side</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>Side opp</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Neste</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Neste side</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>Side ned</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>Rediger dokumenter</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>Nettsurfing</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linje</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>Liten linje</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>Middels linje</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>Store linje</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Avslutt</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>Slettemarkør</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation type="vanished">Liten slettemarkør</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>Middels slettemarkør</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>Stor slettemarkør</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Farge</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Tilbake</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Venstre</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Forover</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Høyre</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Last opp på nytt</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>Last opp denne siden</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Hjem</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>Last opp hjemmesiden</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Bokmerker</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>Vis bokmerker</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>Bokmerke</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Tilføy bokmerke</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>Vis tavle</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>Slett</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>Slett innhold</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Preferanser</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>Vis preferanser</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Bibliotek</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>Vis bibliotek</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>Vis skrivebord</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>Vis datamaskinens skrivebord</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>Større</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Zoom inn</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>Mindre</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Zoom ut</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Ny mappe</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>Opprett en ny mappe</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>Nytt dokument</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>Opprett et nytt dokument</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importer</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>Importer et dokument</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksporter</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>Eksporter et dokument</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>Åpne i tavle</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>Åpne side i tavle</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Dupliser</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>Dupliser valgt innhold</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>Slett valgt innhold</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Slett</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>Legg til arbeidsdokument</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>Legg valgt innhold til åpent dokument</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Legg til</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>Legg innhold til dokument</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Gi nytt navn</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>Gi innhold nytt navn</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Verktøy</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>Vis verktøy</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>Multiskjerm</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>Bred skjermstørrelse (16/9)</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>Bruk dokument i bred skjermstørrelse (16/9)</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>Vanlig skjermstørrelse (4/3)</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>Bruk dokument i vanlig skjermstørrelse (4/3)</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>Tilpasset størrelse</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>Bruk dokument i tilpasset skjermstørrelse</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>Stopp lasting</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>Stopp lasting av nettsiden</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Klipp</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Lim inn</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>Standby</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>Sett presentasjonen i standby</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Virtuelt tastatur</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>Vis virtuelt tastatur</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>Vanlig lys bakgrunn</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Lys</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>Bakgrunn med lys i rutemønster</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>Vanlig mørk bakgrunn</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Mørk</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>Mørk bakgrunn i rutemønster</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>Ta opp presentasjon for video</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Ta opp</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>Start opptak av skjerm</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>Slett enheter</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>Slett alle enheter</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>Slett merknader</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>Slett alle merknader</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>Slett side</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>Slett alle elementer</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Penn</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>Skriv merknader til dokument</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>Slett merknad</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Markør</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>Merk</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>Velger</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>Velg og endre objekter</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>Hånd</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Rull side</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>Laserpeker</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>Virtuell laserpeker</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>Tegn linjer</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>Skriv tekst</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Ta bilde</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Ta bilde av en del av skjermen</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>Legg til denne siden</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>Legg enhet til denne siden</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>Legg til ny side</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>Legg enhet til ny side</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>Legg til bibliotek</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>Legg enhet til bibliotek</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Sider</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>Opprett en ny side</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Ny side</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>Dupliser side</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>Dupliser denne siden</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>Importer side</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>Importer en ekstern side</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>Sett podcastopptak på pause</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>Podcastkonfigurering</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>Konfigurer opptak for podcast</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation>Flash trap</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation>Trap flash-innhold</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>Web trap</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>Trap web-innhold</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>Tilpass bildetakning</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>Ta bilde av vindu</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>Ta bilde av et vindu</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>Legg inn web-innhold</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>Ta bilde av web-innhold som kan legges inn</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>Vis på display</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>Vis hovedskjerm på display</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>Slett alle merknader</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedia</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>Importer simulering av eduMedia</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Sjekk etter oppdateringer</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>Avslutt OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>Skjul Åpne-Sankoré</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>Skjul Åpne-Sankoré-applikasjon</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Spill av</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>Samhandle med enheter</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>Slett bakgrunn</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>Fjern bakgrunn</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Autentisering nødvendig</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Brukernavn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passord:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Proxy-autentisering</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>Koble til proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Brukernavn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passord:</translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>Lagre brukernavn og passord for fremtidig bruk</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation>Element-ID = </translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation>Innhold er ikke støttet i mottaksformat.</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation>Fjern side</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation>Er du sikker på at du vil fjerne side 1 fra det valgte dokumentet &apos;%0&apos;?</translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>Sidestørrelse</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>Ny oppdatering tilgjengelig, vil du gå til nettsiden?</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>Ingen oppdatering tilgjengelig</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>Oppdatering tilgjengelig</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Oppdatering</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>Nedlasting av innhold %1 mislyktes</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Nedlasting avsluttet</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>Ukjent verktøytype %1</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>Ukjent innholdstype %1</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>Legg til enhet</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>Alle støttede (%1)</translation>
    </message>
    <message>
        <source>Delete page %1 from document</source>
        <translation type="vanished">Slett side %1 fra dokument</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation>Side %1 slettet</translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation>Tilføying av fil slo feil: filkopieringsfeil</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Grupper</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>Dele opp</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished">Farge</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>Feil ved tilføying av bilde til bibliotek</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>Tatt bilde</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>Cache-egenskaper</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Farge:</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>Form:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Avslutt</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Ta bilde av en del av skjermen</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>Ta bilde av skjermen</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>Vis stilpaletten</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>Vis tavle på annen skjerm</translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>Vis skrivebord på annen skjerm</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>New Folder</source>
        <translation>Ny mappe
</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>Side %1</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>Legg til mappe med bilder</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>Legg til bilder</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>Legg til sider fra fil</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>Dupliserer dokument %1</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>Dokument %1 kopiert</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">Fjern side</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">Fjern dokument</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">Er du sikker på at du vil fjerne dokumentet &quot;%1&quot;?</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">Tøm søppel</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">Er du sikker på at du vil tømme søppelet?</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">Tømmer søppel</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">Søppel tømt</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">Fjern mappe</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">Er du sikker på at du vil fjerne mappen &quot;%1&quot; med alt innhold?</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">Intet dokument valgt!</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>Åpne støttet fil</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Importerer fil %1...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>Kunne ikke importere fil...</translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>Importer alle bilder fra mappe</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Tøm</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Åpne dokument</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Søppel</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>Åpne dokument</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>Legg alle bilder til dokument</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>Alle bilder (%1)</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>Utvalget inneholder ingen bildefiler!</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>Er du sikker på at du vil fjerne %n siden(e) fra det valgte dokumentet &apos;%1&apos;?</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation>Mappe inneholder ikke noen bildefiler</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation>Dokumenter uten tittel</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>bilder</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>videoer</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>objekter</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>widgets</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>Alle støttede filer (*.%1)</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>Fil %1 lagret</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation>Setter inn side %1 av %2</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importering gjennomført.</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation>Importering av fil %1 gjennomført.</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation>Importerer fil %1</translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>Side %0</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation type="unfinished">Godta</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Avbryt</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>Trash</source>
        <translation type="unfinished">Søppel</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 sider kopiert</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>My documents</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 sider kopiert</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="unfinished">Kopierer side %1/%2</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (kopier)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">Kopierer side %1/%2</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="vanished">
            <numerusform>%1 sider kopiert</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>Nedlasting av filer</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Side %0</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Side %0</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Warnings during export was appeared</source>
        <translation>Advarsler under eksport ble vist</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">Eksporterer dokument ...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">Eksport gjennomført.</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>Eksporter til IWB</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>Eksporter som IWB-fil</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Eksporterer dokument ...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Eksport gjennomført.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Eksport mislyktes.</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>Side</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>Eksporter som UBZ-fil</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Eksporterer dokument ...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Eksport gjennomført.</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>Eksporterer %1 %2 av %3</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">Eksporterer dokument ...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">Eksport gjennomført.</translation>
    </message>
    <message>
        <source>Failed to export...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Eksporter som PDF-fil</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Eksporterer dokument ...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Eksport gjennomført.</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Eksporter til PDF</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Eksporter som PDF-fil</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Eksporterer dokument ...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Eksport gjennomført.</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>Eksporterer side %1 av %2</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Eksporter til PDF</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>Side</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>Eksporter som webdata</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Eksporterer dokument ...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Eksport gjennomført.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Eksportering mislyktes.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>Eksporter til nettleser</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>Legg til side</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="vanished">Bruk som bakgrunn</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>Legg til bibliotek</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>Objektopplysninger</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>Legg til favoritter</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>Tilbake til mappe</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Fjern fra favoritter</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>Opprett ny mappe</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>Skann filsystemet igjen</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>Importert bilde</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation>Lydfiler</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Filmer</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="vanished">Animasjoner</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation>Interaktivitet</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Applikasjoner</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation>Former</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritter</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation>Websøk</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Søppel</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation>Godta</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation>Oppgi et nytt mappenavn</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation>Laster </translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Låst</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Synlig på utvidet skjerm</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Låst</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Synlig på utvidet skjerm</translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>Gå til kildeinnhold</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="unfinished">Bruk som bakgrunn</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;Skriv tekst her&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>Tekstfarge</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>Redigerbar</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation>Laster ...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>Frosset</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>Transformer som verktøy</translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation>Vanlig filformat (</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Importerer fil %1...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Importering av fil %1 mislyktes.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importering gjennomført.</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>Importering mislyktes.</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>Importerer fil %1...</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Importering gjennomført.</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Importering av fil %1 mislyktes.</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>Bildeformat (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Portabelt dokumentformat (*.pdf)</translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>PDF-importering mislyktes.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>Importerer side %1 av %2</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>Feil under publisering av video til intranett (%1)</translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>Publisering til Intranett pågår %1 %</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>Publiser</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translatorcomment>Translation of the key on the keyboard - if it is &quot;Enter the numer X&quot; - It should be &quot;Tast inn nummeret X&quot;</translatorcomment>
        <translation>Enter</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nei</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Tast inn brukernavn og passord for &quot;%1&quot; ved %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>Kunne ikke logge på proxy</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>SSL-feil: %1 %2 Vil du ignorere disse feilene for denne verten?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nei</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Avbryt</translation>
    </message>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(kopier)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>Tap av dokumentdatabase</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>Engelsk</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Russisk</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Tysk</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Fransk</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>Sveitsisk-fransk</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>Kunne ikke starte koder ...</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>Ingen podcast-koder tilgjengelig ...</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>Del %1</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>på ditt skrivebord ...</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>i mappe %1</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>Podcast opprettet %1</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>Opptaksfeil i podcast (%1)</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>Feil i audios innverdi</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>Intet audioopptak</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Liten</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Middels</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Full</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>Publiser til Intranett</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>Publiser til YouTube</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>versjon:</translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>Markøren er trykksensitiv</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">Innlogging proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">Brukernavn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">Passord:</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">Publiser dokument på webben</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">Tittel:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">Beskrivelse:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">Publiser</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>Mine filmer</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>Genererer forhåndsvisning med miniatyrbilder ...</translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>%1 miniatyrbilder generert ...</translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Side %0</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Mask</source>
        <translation>Skjul</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>Linjal</translation>
    </message>
    <message>
        <source>Compass</source>
        <translation>Kompass</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>Gradeskive</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>Triangel</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>Forstørrelsesglass</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>Skjul</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>Hel side</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>Oppdatering av dokument</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation>filer trenger en oppdatering.</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>Filbane sikkerhetskopi:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Bla gjennom</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Oppdatering</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>Velg mappe for sikkerhetskopi</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>Filene ble oppdatert! Vennligst start applikasjonen på nytt for å få tilgang til de oppdaterte dokumentene.</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>En feil oppsto under oppdateringen. Filene har ikke blitt berørt av dette.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>Resultater av filoppdateringen</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>Oppdaterer fil</translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>Vennligst vent, importeringsprosessen vil snart begynne...</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Minn meg på det senere</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>Laster...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 oppringt (metode=%1, status=%2)</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>YouTube-autentisering mislyktes.</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>Feil ved opplasting av video til YouTube (%1)</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>Opplasting til YouTube pågår %1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>Last opp</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>Biler og kjøretøy</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musikk</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>Kjæledyr og andre dyr</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>Sport</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>Reiser og opplevelser</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Spill</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>Komedie</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>Folk og blogger</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>Nyheter og politikk</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>Underholdning</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>Utdanning</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>Gjør-det-selv og interiør</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>Veldedighet og engasjement</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>Vitenskap og teknologi</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Slett</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>Lagre fil</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Nedlasting avbrutt: %1</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>Feil ved åpning av lagret fil: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Feil ved lagring: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Nettverksfeil: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekunder</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutter</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>- %4 %5 gjenværende</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 av %2 (%3/s) %4</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 av %2 - Stopppet</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>1 nedlasting</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1 nedlastinger</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Tittel</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Tidligere i dag</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 enheter</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>Ny og &amp;fane</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>Klone-fane</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;avslutt fane</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Avslutt &amp;andre faner</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Last fane på nytt</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Last alle faner på nytt</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Nylig avsluttede faner</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>(Uten tittel)</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>No Recent Searches</source>
        <translation>Ingen nylige søk</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Nylige søk</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Slett nylige søk</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished">Søk</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>Last ned</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>Legg til aktuelt dokument</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>Feil ved lasting av side: %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>Åpne i ny fane</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Publiser podcast til YouTube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tittel</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Stikkord</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>YouTube brukernavn</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>YouTube passord</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation type="unfinished">OpenBoard</translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>On Light Background</source>
        <translation>Med lys bakgrunn</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Med mørk bakgrunn</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Ugjennomsiktig</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Linjebredde</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Middels</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>Sterk</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>Tynn</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>Pennen er trykksensitiv</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tittel</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>E-post</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Forfatter</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">Dialog</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">Tittel</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="obsolete">E-post</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="obsolete">Forfatter</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">Beskrivelse</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Preferanser</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>versjon: ...</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>Standardinnstillinger</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Avslutt</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Display</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internett</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>Vis side med ekstern nettleser</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Hjemmeside:</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Virtuelt tastatur</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">Tastestørrelse tastatur:</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Verktøylinje</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>Plassert på toppen (anbefalt for minitavler)</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>Plassert nederst (anbefalt for krittavler)</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>Vis tekst under tast</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>Stilpalett</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horisontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertikal</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Penn</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Markør</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>Oppdatering av programvare</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>Sjekk oppdatering av programvare ved oppstart</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>Lisenser</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Nettverk</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>Vis innhold fra internt nettsted på annen skjerm eller projektor</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>Multidisplay</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translatorcomment>I have translated this as swap between cd and vd</translatorcomment>
        <translation>Bytt mellom kontrolldisplay og se display</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>Modus å starte i:</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>Tavle</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Skrivebord</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>Proxy-bruker</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>Pass:</translation>
    </message>
    <message>
        <source>Credits</source>
        <translatorcomment>Translates as &quot;thanks to&quot;</translatorcomment>
        <translation>Takk til</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation type="unfinished">Med mørk bakgrunn</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished">Ugjennomsiktig</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation type="unfinished">Med lys bakgrunn</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>Ta flash</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation>Velg flash som skal tas</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>om:blank</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>Applikasjonsnavn</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>Opprett applikasjon</translation>
    </message>
</context>
</TS>
